==> nextcloud-31.0.10.tgz: nextcloud/apps/circles/l10n/ko.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "{circle} 팀을 생성했습니다.",
    "{author} created the team {circle}" : "유저 {author}이/가 팀  {circle}을 생성했습니다.",
    "You deleted {circle}" : "여러분이 {circle}을(를) 삭제함",
    "{author} deleted {circle}" : "{author} 님이 {circle}을(를) 삭제함",
    "You made {member} join {circle}" : "{member}를 {circle}에 할당했습니다.",
    "{author} made {member} join {circle}" : "유저 {author}이/가 {member}를 {circle}에 할당했습니다.",
    "You removed {member} from {circle}" : "여러분이 {member} 님을 {circle}에서 삭제함",
    "You joined {circle}" : "여러분이 {circle}에 참가함",
    "{member} joined {circle}" : "{member} 님이 {circle}에 참가함",
    "You accepted the invitation to join {circle}" : "여러분이 {circle}에 등록할 초대장을 수락함",
    "{member} accepted the invitation to join {circle}" : "{member} 님이 {circle}에 등록할 초대장을 수락함",
    "You added {member} as member to {circle}" : "여러분이 {member} 님을 {circle}의 회원으로 추가함",
    "You have been added as member to {circle} by {author}" : "{author} 님이 여러분을 {circle}의 회원으로 추가함",
    "{member} has been added as member to {circle} by {author}" : "{author} 님이 {member} 님을 {circle}의 회원으로 추가함",
    "You added {external} to {circle}" : "여러분이 {external}을(를) {circle}에 추가함",
    "{external} has been added to {circle} by {author}" : "{author} 님이 {external}을(를) {circle}에 추가함",
    "You accepted {member}'s request to join {circle}" : "여러분이 {member} 님의 {circle} 가입 요청을 수락함",
    "Your request to join {circle} has been accepted by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 수락함",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 수락함",
    "You left {circle}" : "여러분이 {circle}을 떠남",
    "{member} left {circle}" : "{member} 님이 {circle}을(를) 떠남",
    "You declined the invitation to join {circle}" : "여러분이 {circle}에 등록할 초대장을 거절함",
    "{member} declined an invitation to join {circle}" : "{member} 님이 {circle}에 등록할 초대장을 거절함",
    "You cancelled your request to join {circle}" : "여러분이 {circle} 가입 요청을 취소함",
    "You have been removed from {circle} by {author}" : "{author} 님이 여러분을 {circle}에서 삭제함",
    "{member} has been removed from {circle} by {author}" : "{author} 님이 {member} 님을 {circle}에서 삭제함",
    "You removed {external} from {circle}" : "여러분이 {external}을(를) {circle}에서 삭제함",
    "{external} has been removed from {circle} by {author}" : "{author} 님이 {external}을(를) {circle}에서 삭제함",
    "You cancelled {member}'s invitation to join {circle}" : "여러분이 {member} 님의 {circle} 가입 요청을 취소함",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 취소함",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 취소함",
    "You dismissed {member}'s request to join {circle}" : "{member} 님의 {circle} 가입 요청을 삭제함",
    "Your request to join {circle} has been dismissed by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 삭제함",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 삭제함",
    "You invited {member} to join {circle}" : "여러분이 {circle}에 {member} 님을 초대함",
    "You have been invited to join {circle} by {author}" : "{author} 님이 여러분을 {circle}에 초대함",
    "{member} has been invited to join {circle} by {author}" : "{author} 님이 {member} 님을 {circle}에 초대함",
    "You changed {member}'s level in {circle} to %1$s" : "여러분이 {circle}의 {member}의 단계를 %1$s(으)로 변경함",
    "{author} changed your level in {circle} to %1$s" : "{author} 님이 {circle}의 내 단계를 %1$s(으)로 변경함",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 님이 {circle}의 {member}의 단계를 %1$s(으)로 변경함",
    "You sent a request to join {circle}" : "여러분이 {circle} 가입 요청을 보냄",
    "{member} sent a request to join {circle}" : "{member} 님이 {circle} 가입 요청을 보냄",
    "You are the new owner of {circle}" : "여러분이 {circle}의 새 소유자가 됨",
    "{member} is the new owner of {circle}" : "{member} 님이 {circle}의 새 소유자가 됨",
    "Personal" : "개인",
    "System" : "시스템",
    "Visible" : "보임",
    "Open" : "열기",
    "Invite" : "초대",
    "Friends" : "친구",
    "Password protected" : "암호로 보호됨",
    "No Owner" : "소유자 없음",
    "Hidden" : "숨겨짐",
    "Backend" : "백엔드",
    "Local" : "로컬",
    "Root" : "루트",
    "Federated" : "연합",
    "Nextcloud Account" : "Nextcloud 계정",
    "Nextcloud Group" : "Nextcloud 그룹",
    "Email address" : "이메일 주소",
    "Contact" : "연락처",
    "Team" : "팀",
    "Nextcloud App" : "Nextcloud 앱",
    "Member" : "회원",
    "Moderator" : "중재자",
    "Admin" : "관리자",
    "Owner" : "소유자",
    "%s shared »%s« with you." : "%s 님이 \"%s\"을(를) 공유했습니다.",
    "%s shared »%s« with \"%s\"." : "%s님이 »%s«을(를) \"%s\"와(과) 공유했습니다.",
    "%s on %s" : "%s(%s의)",
    "Password to access »%s«" : "%s에 접근할 수 있는 암호",
    "It is protected with the following password:" : "다음 암호로 보호됩니다:",
    "%1$s via %2$s" : "%1$s(%2$s 경유)",
    "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
    "Open »%s«" : "%s 열기",
    "Password to access files shared to you by %1$s" : "%1$s님이 공유한 파일에 접근하기 위한 암호",
    "Password to access files" : "파일에 접근하기 위한 암호",
    "%s shared multiple files with \"%s\"." : "%s님이 \"%s\"와(과) 여러 파일을 공유했습니다.",
    "%s shared multiple files with you." : "%s님이 여러 파일을 공유했습니다.",
    "Testing Basic Circle Creation" : "기본 서클 생성 테스트 중",
    "Adding local users and moderators" : "로컬 사용자와 중재자 추가 중",
    "Files" : "파일",
    "This feature is not available for personal circles" : "이 기능은 개인 서클에서 사용할 수 없음",
    "This member is not a moderator" : "이 회원은 중재자가 아님",
    "Insufficient privileges" : "권한이 부족함",
    "This member does not exist" : "이 회원이 존재하지 않음",
    "Level cannot be changed for this type of member" : "이 회원의 단계를 변경할 수 없음",
    "You are already a member of this circle" : "이미 서클 회원임",
    "You have been blocked from this circle" : "이 서클에서 차단됨",
    "The account is already a member of this circle" : "이 계정은 이미 이 서클의 회원임",
    "The account has already been invited into this circle" : "이 계정을 이미 이 서클에 초대함",
    "Accept" : "수락",
    "%s" : "%s",
    "%s owned by %s" : "%s이(가) 소유한 %s",
    "%s shared a file with \"%s\"." : "%s님이 \"%s\"에게 파일을 공유했습니다.",
    "%s shared a file with you." : "%s님이 파일을 공유했습니다.",
    "Open %s" : "%s 열기",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s님이 공유한 것이 있습니다. \n함께 발송한 별도의 이메일에서 링크를 눌러 이 공유에 접근하십시오.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s님이 공유한 것이 있습니다.\n함께 발송한 별도의 이메일에서 링크를 눌로 이 공유에 접근하십시오.",
    "Password to access content shared with you by %1$s" : "%1$s님의 공유에 접근하기 위한 암호",
    "Bring cloud-users closer together." : "클라우드 사용자를 더 가깝게 연결합니다.",
    "Try again" : "다시 시도",
    "Loading…" : "불러오는 중…",
    "No files in here" : "여기에 파일 없음",
    "No entries found in this folder" : "이 폴더에서 항목을 찾을 수 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정한 날짜",
    "Shared to Circles" : "서클에 공유됨"
},
"nplurals=1; plural=0;");

==> nextcloud-31.0.11.tgz: nextcloud/apps/circles/l10n/ko.js <==
OC.L10N.register(
    "circles",
    {
    "You created the team {circle}" : "{circle} 팀을 생성했습니다.",
    "{author} created the team {circle}" : "유저 {author}이/가 팀  {circle}을 생성했습니다.",
    "You deleted {circle}" : "여러분이 {circle}을(를) 삭제함",
    "{author} deleted {circle}" : "{author} 님이 {circle}을(를) 삭제함",
    "You made {member} join {circle}" : "{member}를 {circle}에 할당했습니다.",
    "{author} made {member} join {circle}" : "유저 {author}이/가 {member}를 {circle}에 할당했습니다.",
    "You removed {member} from {circle}" : "여러분이 {member} 님을 {circle}에서 삭제함",
    "You joined {circle}" : "여러분이 {circle}에 참가함",
    "{member} joined {circle}" : "{member} 님이 {circle}에 참가함",
    "You accepted the invitation to join {circle}" : "여러분이 {circle}에 등록할 초대장을 수락함",
    "{member} accepted the invitation to join {circle}" : "{member} 님이 {circle}에 등록할 초대장을 수락함",
    "You added {member} as member to {circle}" : "여러분이 {member} 님을 {circle}의 회원으로 추가함",
    "You have been added as member to {circle} by {author}" : "{author} 님이 여러분을 {circle}의 회원으로 추가함",
    "{member} has been added as member to {circle} by {author}" : "{author} 님이 {member} 님을 {circle}의 회원으로 추가함",
    "You added {external} to {circle}" : "여러분이 {external}을(를) {circle}에 추가함",
    "{external} has been added to {circle} by {author}" : "{author} 님이 {external}을(를) {circle}에 추가함",
    "You accepted {member}'s request to join {circle}" : "여러분이 {member} 님의 {circle} 가입 요청을 수락함",
    "Your request to join {circle} has been accepted by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 수락함",
    "{member}'s request to join {circle} has been accepted by {author}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 수락함",
    "You left {circle}" : "여러분이 {circle}을 떠남",
    "{member} left {circle}" : "{member} 님이 {circle}을(를) 떠남",
    "You declined the invitation to join {circle}" : "여러분이 {circle}에 등록할 초대장을 거절함",
    "{member} declined an invitation to join {circle}" : "{member} 님이 {circle}에 등록할 초대장을 거절함",
    "You cancelled your request to join {circle}" : "여러분이 {circle} 가입 요청을 취소함",
    "You have been removed from {circle} by {author}" : "{author} 님이 여러분을 {circle}에서 삭제함",
    "{member} has been removed from {circle} by {author}" : "{author} 님이 {member} 님을 {circle}에서 삭제함",
    "You removed {external} from {circle}" : "여러분이 {external}을(를) {circle}에서 삭제함",
    "{external} has been removed from {circle} by {author}" : "{author} 님이 {external}을(를) {circle}에서 삭제함",
    "You cancelled {member}'s invitation to join {circle}" : "여러분이 {member} 님의 {circle} 가입 요청을 취소함",
    "Your invitation to join {circle} has been cancelled by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 취소함",
    "{author} cancelled {member}'s invitation to join {circle}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 취소함",
    "You dismissed {member}'s request to join {circle}" : "{member} 님의 {circle} 가입 요청을 삭제함",
    "Your request to join {circle} has been dismissed by {author}" : "{author} 님이 여러분의 {circle} 가입 요청을 삭제함",
    "{member}'s request to join {circle} has been dismissed by {author}" : "{author} 님이 {member} 님의 {circle} 가입 요청을 삭제함",
    "You invited {member} to join {circle}" : "여러분이 {circle}에 {member} 님을 초대함",
    "You have been invited to join {circle} by {author}" : "{author} 님이 여러분을 {circle}에 초대함",
    "{member} has been invited to join {circle} by {author}" : "{author} 님이 {member} 님을 {circle}에 초대함",
    "You changed {member}'s level in {circle} to %1$s" : "여러분이 {circle}의 {member}의 단계를 %1$s(으)로 변경함",
    "{author} changed your level in {circle} to %1$s" : "{author} 님이 {circle}의 내 단계를 %1$s(으)로 변경함",
    "{author} changed {member}'s level in {circle} to %1$s" : "{author} 님이 {circle}의 {member}의 단계를 %1$s(으)로 변경함",
    "You sent a request to join {circle}" : "여러분이 {circle} 가입 요청을 보냄",
    "{member} sent a request to join {circle}" : "{member} 님이 {circle} 가입 요청을 보냄",
    "You are the new owner of {circle}" : "여러분이 {circle}의 새 소유자가 됨",
    "{member} is the new owner of {circle}" : "{member} 님이 {circle}의 새 소유자가 됨",
    "Personal" : "개인",
    "System" : "시스템",
    "Visible" : "보임",
    "Open" : "열기",
    "Invite" : "초대",
    "Friends" : "친구",
    "Password protected" : "암호로 보호됨",
    "No Owner" : "소유자 없음",
    "Hidden" : "숨겨짐",
    "Backend" : "백엔드",
    "Local" : "로컬",
    "Root" : "루트",
    "Federated" : "연합",
    "Nextcloud Account" : "Nextcloud 계정",
    "Nextcloud Group" : "Nextcloud 그룹",
    "Email address" : "이메일 주소",
    "Contact" : "연락처",
    "Team" : "팀",
    "Nextcloud App" : "Nextcloud 앱",
    "Member" : "회원",
    "Moderator" : "중재자",
    "Admin" : "관리자",
    "Owner" : "소유자",
    "%s shared »%s« with you." : "%s 님이 \"%s\"을(를) 공유했습니다.",
    "%s shared »%s« with \"%s\"." : "%s님이 »%s«을(를) \"%s\"와(과) 공유했습니다.",
    "%s on %s" : "%s(%s의)",
    "Password to access »%s«" : "%s에 접근할 수 있는 암호",
    "It is protected with the following password:" : "다음 암호로 보호됩니다:",
    "%1$s via %2$s" : "%1$s(%2$s 경유)",
    "Click the button below to open it." : "아래 단추를 눌러서 열 수 있습니다.",
    "Open »%s«" : "%s 열기",
    "Password to access files shared to you by %1$s" : "%1$s님이 공유한 파일에 접근하기 위한 암호",
    "Password to access files" : "파일에 접근하기 위한 암호",
    "%s shared multiple files with \"%s\"." : "%s님이 \"%s\"와(과) 여러 파일을 공유했습니다.",
    "%s shared multiple files with you." : "%s님이 여러 파일을 공유했습니다.",
    "Adding local users and moderators" : "로컬 사용자와 중재자 추가 중",
    "Files" : "파일",
    "This member is not a moderator" : "이 회원은 중재자가 아님",
    "Insufficient privileges" : "권한이 부족함",
    "This member does not exist" : "이 회원이 존재하지 않음",
    "Level cannot be changed for this type of member" : "이 회원의 단계를 변경할 수 없음",
    "Accept" : "수락",
    "%s" : "%s",
    "%s owned by %s" : "%s이(가) 소유한 %s",
    "%s shared a file with \"%s\"." : "%s님이 \"%s\"에게 파일을 공유했습니다.",
    "%s shared a file with you." : "%s님이 파일을 공유했습니다.",
    "Open %s" : "%s 열기",
    "%1$s shared some content with you.\nYou should have already received a separate email with a link to access it.\n" : "%1$s님이 공유한 것이 있습니다. \n함께 발송한 별도의 이메일에서 링크를 눌러 이 공유에 접근하십시오.\n",
    "%1$s shared some content with you. You should have already received a separate email with a link to access it." : "%1$s님이 공유한 것이 있습니다.\n함께 발송한 별도의 이메일에서 링크를 눌로 이 공유에 접근하십시오.",
    "Password to access content shared with you by %1$s" : "%1$s님의 공유에 접근하기 위한 암호",
    "Bring cloud-users closer together." : "클라우드 사용자를 더 가깝게 연결합니다.",
    "Try again" : "다시 시도",
    "Loading…" : "불러오는 중…",
    "No files in here" : "여기에 파일 없음",
    "No entries found in this folder" : "이 폴더에서 항목을 찾을 수 없음",
    "Name" : "이름",
    "Size" : "크기",
    "Modified" : "수정한 날짜",
    "Shared to Circles" : "서클에 공유됨",
    "Testing Basic Circle Creation" : "기본 서클 생성 테스트 중",
    "This feature is not available for personal circles" : "이 기능은 개인 서클에서 사용할 수 없음",
    "You are already a member of this circle" : "이미 서클 회원임",
    "You have been blocked from this circle" : "이 서클에서 차단됨",
    "The account is already a member of this circle" : "이 계정은 이미 이 서클의 회원임",
    "The account has already been invited into this circle" : "이 계정을 이미 이 서클에 초대함"
},
"nplurals=1; plural=0;");
